@@ -1,7 +1,7 @@
 #ifndef __GDKCONFIG_H__
 #define __GDKCONFIG_H__
 
-#if !defined (__GDK_H_INSIDE__) && !defined (GDK_COMPILATION)
+#if !defined (__GDK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gdk/gdk.h> can be included directly."
 #endif
 
@@ -14,7 +14,6 @@ G_BEGIN_DECLS
 #undef GDK_WINDOWING_BROADWAY
 #undef GDK_WINDOWING_WAYLAND
 #undef GDK_WINDOWING_WIN32
-/* #undef GDK_WINDOWING_MIR */
 
 #undef GDK_RENDERING_VULKAN
 
