@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -29,32 +27,33 @@
 
 #define __GTK_H_INSIDE__
 
+#include <gtk/css/gtkcss.h>
 #include <gdk/gdk.h>
+#include <gsk/gsk.h>
+
 #include <gtk/gtkaboutdialog.h>
 #include <gtk/gtkaccelgroup.h>
 #include <gtk/gtkaccellabel.h>
-#include <gtk/gtkaccelmap.h>
 #include <gtk/gtkaccessible.h>
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkactivatable.h>
+#include <gtk/gtkactionable.h>
+#include <gtk/gtkactionbar.h>
 #include <gtk/gtkadjustment.h>
-#include <gtk/gtkalignment.h>
 #include <gtk/gtkappchooser.h>
 #include <gtk/gtkappchooserdialog.h>
 #include <gtk/gtkappchooserwidget.h>
 #include <gtk/gtkappchooserbutton.h>
 #include <gtk/gtkapplication.h>
-#include <gtk/gtkarrow.h>
+#include <gtk/gtkapplicationwindow.h>
 #include <gtk/gtkaspectframe.h>
 #include <gtk/gtkassistant.h>
-#include <gtk/gtkbbox.h>
 #include <gtk/gtkbin.h>
-#include <gtk/gtkbindings.h>
+#include <gtk/gtkbinlayout.h>
 #include <gtk/gtkborder.h>
+#include <gtk/gtkboxlayout.h>
 #include <gtk/gtkbox.h>
 #include <gtk/gtkbuildable.h>
 #include <gtk/gtkbuilder.h>
+#include <gtk/gtkbuilderscope.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkcalendar.h>
 #include <gtk/gtkcellarea.h>
@@ -72,143 +71,170 @@
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkcellrenderertoggle.h>
 #include <gtk/gtkcellview.h>
+#include <gtk/gtkcenterbox.h>
+#include <gtk/gtkcenterlayout.h>
 #include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkcheckmenuitem.h>
-#include <gtk/gtkclipboard.h>
 #include <gtk/gtkcolorbutton.h>
-#include <gtk/gtkcolorsel.h>
-#include <gtk/gtkcolorseldialog.h>
+#include <gtk/gtkcolorchooser.h>
+#include <gtk/gtkcolorchooserdialog.h>
+#include <gtk/gtkcolorchooserwidget.h>
+#include <gtk/gtkcolorutils.h>
 #include <gtk/gtkcombobox.h>
 #include <gtk/gtkcomboboxtext.h>
+#include <gtk/gtkconstraintlayout.h>
+#include <gtk/gtkconstraint.h>
 #include <gtk/gtkcontainer.h>
 #include <gtk/gtkcssprovider.h>
+#include <gtk/gtkcustomlayout.h>
 #include <gtk/gtkdebug.h>
 #include <gtk/gtkdialog.h>
-#include <gtk/gtkdnd.h>
+#include <gtk/gtkdragicon.h>
+#include <gtk/gtkdragsource.h>
 #include <gtk/gtkdrawingarea.h>
+#include <gtk/gtkdropcontrollermotion.h>
+#include <gtk/gtkdroptarget.h>
+#include <gtk/gtkdroptargetasync.h>
 #include <gtk/gtkeditable.h>
+#include <gtk/gtkemojichooser.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkentrybuffer.h>
 #include <gtk/gtkentrycompletion.h>
 #include <gtk/gtkenums.h>
-#include <gtk/gtkeventbox.h>
+#include <gtk/gtkeventcontroller.h>
+#include <gtk/gtkeventcontrollerfocus.h>
+#include <gtk/gtkeventcontrollerkey.h>
+#include <gtk/gtkeventcontrollerlegacy.h>
+#include <gtk/gtkeventcontrollermotion.h>
+#include <gtk/gtkeventcontrollerscroll.h>
 #include <gtk/gtkexpander.h>
 #include <gtk/gtkfixed.h>
+#include <gtk/gtkfixedlayout.h>
 #include <gtk/gtkfilechooser.h>
 #include <gtk/gtkfilechooserbutton.h>
 #include <gtk/gtkfilechooserdialog.h>
+#include <gtk/gtkfilechoosernative.h>
 #include <gtk/gtkfilechooserwidget.h>
 #include <gtk/gtkfilefilter.h>
+#include <gtk/gtkfilterlistmodel.h>
+#include <gtk/gtkflattenlistmodel.h>
+#include <gtk/gtkflowbox.h>
 #include <gtk/gtkfontbutton.h>
-#include <gtk/gtkfontsel.h>
+#include <gtk/gtkfontchooser.h>
+#include <gtk/gtkfontchooserdialog.h>
+#include <gtk/gtkfontchooserwidget.h>
 #include <gtk/gtkframe.h>
-#include <gtk/gtkgradient.h>
+#include <gtk/gtkgesture.h>
+#include <gtk/gtkgestureclick.h>
+#include <gtk/gtkgesturedrag.h>
+#include <gtk/gtkgesturelongpress.h>
+#include <gtk/gtkgesturepan.h>
+#include <gtk/gtkgesturerotate.h>
+#include <gtk/gtkgesturesingle.h>
+#include <gtk/gtkgesturestylus.h>
+#include <gtk/gtkgestureswipe.h>
+#include <gtk/gtkgesturezoom.h>
+#include <gtk/gtkglarea.h>
 #include <gtk/gtkgrid.h>
-#include <gtk/gtkhandlebox.h>
-#include <gtk/gtkhbbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkhpaned.h>
-#include <gtk/gtkhscale.h>
-#include <gtk/gtkhscrollbar.h>
-#include <gtk/gtkhseparator.h>
-#include <gtk/gtkhsv.h>
-#include <gtk/gtkiconfactory.h>
+#include <gtk/gtkgridlayout.h>
+#include <gtk/gtkheaderbar.h>
 #include <gtk/gtkicontheme.h>
 #include <gtk/gtkiconview.h>
 #include <gtk/gtkimage.h>
-#include <gtk/gtkimagemenuitem.h>
 #include <gtk/gtkimcontext.h>
 #include <gtk/gtkimcontextsimple.h>
 #include <gtk/gtkimmulticontext.h>
 #include <gtk/gtkinfobar.h>
-#include <gtk/gtkinvisible.h>
 #include <gtk/gtklabel.h>
-#include <gtk/gtklayout.h>
+#include <gtk/gtklayoutmanager.h>
+#include <gtk/gtklayoutchild.h>
+#include <gtk/gtklevelbar.h>
 #include <gtk/gtklinkbutton.h>
+#include <gtk/gtklistbox.h>
 #include <gtk/gtkliststore.h>
+#include <gtk/gtklockbutton.h>
 #include <gtk/gtkmain.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenubar.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkmenushell.h>
-#include <gtk/gtkmenutoolbutton.h>
+#include <gtk/gtkmaplistmodel.h>
+#include <gtk/gtkmediacontrols.h>
+#include <gtk/gtkmediafile.h>
+#include <gtk/gtkmediastream.h>
+#include <gtk/gtkmenubutton.h>
 #include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkmisc.h>
-#include <gtk/gtkmodules.h>
 #include <gtk/gtkmountoperation.h>
+#include <gtk/gtknative.h>
+#include <gtk/gtknativedialog.h>
+#include <gtk/gtknoselection.h>
 #include <gtk/gtknotebook.h>
-#include <gtk/gtknumerableicon.h>
-#include <gtk/gtkoffscreenwindow.h>
 #include <gtk/gtkorientable.h>
+#include <gtk/gtkoverlay.h>
+#include <gtk/gtkpadcontroller.h>
 #include <gtk/gtkpagesetup.h>
-#include <gtk/gtkpapersize.h>
 #include <gtk/gtkpaned.h>
+#include <gtk/gtkpapersize.h>
+#include <gtk/gtkpasswordentry.h>
+#include <gtk/gtkpicture.h>
+#include <gtk/gtkpopover.h>
+#include <gtk/gtkpopovermenu.h>
+#include <gtk/gtkpopovermenubar.h>
 #include <gtk/gtkprintcontext.h>
 #include <gtk/gtkprintoperation.h>
 #include <gtk/gtkprintoperationpreview.h>
 #include <gtk/gtkprintsettings.h>
 #include <gtk/gtkprogressbar.h>
-#include <gtk/gtkradioaction.h>
 #include <gtk/gtkradiobutton.h>
-#include <gtk/gtkradiomenuitem.h>
-#include <gtk/gtkradiotoolbutton.h>
 #include <gtk/gtkrange.h>
-#include <gtk/gtkrc.h>
-#include <gtk/gtkrecentaction.h>
-#include <gtk/gtkrecentchooser.h>
-#include <gtk/gtkrecentchooserdialog.h>
-#include <gtk/gtkrecentchoosermenu.h>
-#include <gtk/gtkrecentchooserwidget.h>
-#include <gtk/gtkrecentfilter.h>
 #include <gtk/gtkrecentmanager.h>
+#include <gtk/gtkrender.h>
+#include <gtk/gtkrevealer.h>
+#include <gtk/gtkroot.h>
 #include <gtk/gtkscale.h>
 #include <gtk/gtkscalebutton.h>
 #include <gtk/gtkscrollable.h>
 #include <gtk/gtkscrollbar.h>
 #include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkselection.h>
+#include <gtk/gtksearchbar.h>
+#include <gtk/gtksearchentry.h>
+#include <gtk/gtkselectionmodel.h>
 #include <gtk/gtkseparator.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtkseparatortoolitem.h>
 #include <gtk/gtksettings.h>
+#include <gtk/gtkshortcut.h>
+#include <gtk/gtkshortcutaction.h>
+#include <gtk/gtkshortcutcontroller.h>
+#include <gtk/gtkshortcutlabel.h>
+#include <gtk/gtkshortcutmanager.h>
+#include <gtk/gtkshortcutsgroup.h>
+#include <gtk/gtkshortcutssection.h>
+#include <gtk/gtkshortcutsshortcut.h>
+#include <gtk/gtkshortcutswindow.h>
+#include <gtk/gtkshortcuttrigger.h>
 #include <gtk/gtkshow.h>
+#include <gtk/gtksingleselection.h>
+#include <gtk/gtkslicelistmodel.h>
+#include <gtk/gtksnapshot.h>
+#include <gtk/gtksortlistmodel.h>
+#include <gtk/gtkstacksidebar.h>
 #include <gtk/gtksizegroup.h>
 #include <gtk/gtksizerequest.h>
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtkspinner.h>
+#include <gtk/gtkstack.h>
+#include <gtk/gtkstackswitcher.h>
 #include <gtk/gtkstatusbar.h>
-#include <gtk/gtkstatusicon.h>
-#include <gtk/gtkstock.h>
 #include <gtk/gtkstylecontext.h>
-#include <gtk/gtkstyleproperties.h>
 #include <gtk/gtkstyleprovider.h>
-#include <gtk/gtkstyle.h>
 #include <gtk/gtkswitch.h>
-#include <gtk/gtksymboliccolor.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtktearoffmenuitem.h>
-#include <gtk/gtktextattributes.h>
+#include <gtk/gtktext.h>
 #include <gtk/gtktextbuffer.h>
-#include <gtk/gtktextbufferrichtext.h>
 #include <gtk/gtktextchild.h>
 #include <gtk/gtktextiter.h>
 #include <gtk/gtktextmark.h>
 #include <gtk/gtktexttag.h>
 #include <gtk/gtktexttagtable.h>
 #include <gtk/gtktextview.h>
-#include <gtk/gtkthemingengine.h>
-#include <gtk/gtktoggleaction.h>
 #include <gtk/gtktogglebutton.h>
-#include <gtk/gtktoggletoolbutton.h>
-#include <gtk/gtktoolbar.h>
-#include <gtk/gtktoolbutton.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtktoolitemgroup.h>
-#include <gtk/gtktoolpalette.h>
-#include <gtk/gtktoolshell.h>
 #include <gtk/gtktooltip.h>
 #include <gtk/gtktestutils.h>
 #include <gtk/gtktreednd.h>
+#include <gtk/gtktreelistmodel.h>
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtktreemodelfilter.h>
 #include <gtk/gtktreemodelsort.h>
@@ -218,19 +244,17 @@
 #include <gtk/gtktreeview.h>
 #include <gtk/gtktreeviewcolumn.h>
 #include <gtk/gtktypebuiltins.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkvbbox.h>
-#include <gtk/gtkvbox.h>
+#include <gtk/gtktypes.h>
 #include <gtk/gtkversion.h>
+#include <gtk/gtkvideo.h>
 #include <gtk/gtkviewport.h>
 #include <gtk/gtkvolumebutton.h>
-#include <gtk/gtkvpaned.h>
-#include <gtk/gtkvscale.h>
-#include <gtk/gtkvscrollbar.h>
-#include <gtk/gtkvseparator.h>
 #include <gtk/gtkwidget.h>
-#include <gtk/gtkwidgetpath.h>
+#include <gtk/gtkwidgetpaintable.h>
 #include <gtk/gtkwindow.h>
+#include <gtk/gtkwindowgroup.h>
+
+#include <gtk/gtk-autocleanups.h>
 
 #undef __GTK_H_INSIDE__
 
