@@ -41,7 +41,6 @@ G_BEGIN_DECLS
 
 typedef struct _GtkCellArea              GtkCellArea;
 typedef struct _GtkCellAreaClass         GtkCellAreaClass;
-typedef struct _GtkCellAreaPrivate       GtkCellAreaPrivate;
 typedef struct _GtkCellAreaContext       GtkCellAreaContext;
 
 /**
@@ -95,8 +94,6 @@ struct _GtkCellArea
 {
   /*< private >*/
   GInitiallyUnowned parent_instance;
-
-  GtkCellAreaPrivate *priv;
 };
 
 
@@ -112,7 +109,7 @@ struct _GtkCellArea
  * @event: Handle an event in the area, this is generally used to activate
  *     a cell at the event location for button events but can also be used
  *     to generically pass events to #GtkWidgets drawn onto the area.
- * @render: Actually render the area’s cells to the specified rectangle,
+ * @snapshot: Actually snapshot the area’s cells to the specified rectangle,
  *     @background_area should be correctly distributed to the cells
  *     corresponding background areas.
  * @apply_attributes: Apply the cell attributes to the cells. This is
@@ -198,10 +195,10 @@ struct _GtkCellAreaClass
                                                           GdkEvent                *event,
                                                           const GdkRectangle      *cell_area,
                                                           GtkCellRendererState     flags);
-  void               (* render)                          (GtkCellArea             *area,
+  void               (* snapshot)                        (GtkCellArea             *area,
                                                           GtkCellAreaContext      *context,
                                                           GtkWidget               *widget,
-                                                          cairo_t                 *cr,
+                                                          GtkSnapshot             *snapshot,
                                                           const GdkRectangle      *background_area,
                                                           const GdkRectangle      *cell_area,
                                                           GtkCellRendererState     flags,
@@ -265,15 +262,7 @@ struct _GtkCellAreaClass
 
   /*< private >*/
 
-  /* Padding for future expansion */
-  void (*_gtk_reserved1) (void);
-  void (*_gtk_reserved2) (void);
-  void (*_gtk_reserved3) (void);
-  void (*_gtk_reserved4) (void);
-  void (*_gtk_reserved5) (void);
-  void (*_gtk_reserved6) (void);
-  void (*_gtk_reserved7) (void);
-  void (*_gtk_reserved8) (void);
+  gpointer padding[8];
 };
 
 GDK_AVAILABLE_IN_ALL
@@ -309,10 +298,10 @@ gint                  gtk_cell_area_event                          (GtkCellArea
                                                                     const GdkRectangle   *cell_area,
                                                                     GtkCellRendererState  flags);
 GDK_AVAILABLE_IN_ALL
-void                  gtk_cell_area_render                         (GtkCellArea          *area,
+void                  gtk_cell_area_snapshot                       (GtkCellArea          *area,
                                                                     GtkCellAreaContext   *context,
                                                                     GtkWidget            *widget,
-                                                                    cairo_t              *cr,
+                                                                    GtkSnapshot          *snapshot,
                                                                     const GdkRectangle   *background_area,
                                                                     const GdkRectangle   *cell_area,
                                                                     GtkCellRendererState  flags,
@@ -388,6 +377,11 @@ GDK_AVAILABLE_IN_ALL
 void                  gtk_cell_area_attribute_disconnect           (GtkCellArea        *area,
                                                                     GtkCellRenderer    *renderer,
                                                                     const gchar        *attribute);
+GDK_AVAILABLE_IN_ALL
+gint                  gtk_cell_area_attribute_get_column           (GtkCellArea        *area,
+                                                                    GtkCellRenderer    *renderer,
+                                                                    const gchar        *attribute);
+
 
 /* Cell Properties */
 GDK_AVAILABLE_IN_ALL
