@@ -65,11 +65,9 @@ struct _GtkScaleButtonClass
   void	(* value_changed) (GtkScaleButton *button,
                            gdouble         value);
 
-  /* Padding for future expansion */
-  void (*_gtk_reserved1) (void);
-  void (*_gtk_reserved2) (void);
-  void (*_gtk_reserved3) (void);
-  void (*_gtk_reserved4) (void);
+  /*< private >*/
+
+  gpointer padding[8];
 };
 
 GDK_AVAILABLE_IN_ALL
