@@ -22,11 +22,11 @@
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
+#include <gtk/css/gtkcss.h>
+
 #include <gtk/gtkborder.h>
-#include <gtk/gtkcsssection.h>
 #include <gtk/gtkstyleprovider.h>
 #include <gtk/gtktypes.h>
-#include <atk/atk.h>
 
 G_BEGIN_DECLS
 
@@ -38,12 +38,10 @@ G_BEGIN_DECLS
 #define GTK_STYLE_CONTEXT_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS  ((o), GTK_TYPE_STYLE_CONTEXT, GtkStyleContextClass))
 
 typedef struct _GtkStyleContextClass GtkStyleContextClass;
-typedef struct _GtkStyleContextPrivate GtkStyleContextPrivate;
 
 struct _GtkStyleContext
 {
   GObject parent_object;
-  GtkStyleContextPrivate *priv;
 };
 
 struct _GtkStyleContextClass
@@ -59,92 +57,6 @@ struct _GtkStyleContextClass
   void (*_gtk_reserved4) (void);
 };
 
-/* Default set of properties that GtkStyleContext may contain */
-
-/**
- * GTK_STYLE_PROPERTY_BACKGROUND_COLOR:
- *
- * A property holding the background color of rendered elements as a #GdkRGBA.
- */
-#define GTK_STYLE_PROPERTY_BACKGROUND_COLOR "background-color"
-
-/**
- * GTK_STYLE_PROPERTY_COLOR:
- *
- * A property holding the foreground color of rendered elements as a #GdkRGBA.
- */
-#define GTK_STYLE_PROPERTY_COLOR "color"
-
-/**
- * GTK_STYLE_PROPERTY_FONT:
- *
- * A property holding the font properties used when rendering text
- * as a #PangoFontDescription.
- */
-#define GTK_STYLE_PROPERTY_FONT "font"
-
-/**
- * GTK_STYLE_PROPERTY_PADDING:
- *
- * A property holding the rendered element’s padding as a #GtkBorder. The
- * padding is defined as the spacing between the inner part of the element border
- * and its child. It’s the innermost spacing property of the padding/border/margin
- * series.
- */
-#define GTK_STYLE_PROPERTY_PADDING "padding"
-
-/**
- * GTK_STYLE_PROPERTY_BORDER_WIDTH:
- *
- * A property holding the rendered element’s border width in pixels as
- * a #GtkBorder. The border is the intermediary spacing property of the
- * padding/border/margin series.
- *
- * gtk_render_frame() uses this property to find out the frame line width,
- * so #GtkWidgets rendering frames may need to add up this padding when
- * requesting size
- */
-#define GTK_STYLE_PROPERTY_BORDER_WIDTH "border-width"
-
-/**
- * GTK_STYLE_PROPERTY_MARGIN:
- *
- * A property holding the rendered element’s margin as a #GtkBorder. The
- * margin is defined as the spacing between the border of the element
- * and its surrounding elements. It is external to #GtkWidget's
- * size allocations, and the most external spacing property of the
- * padding/border/margin series.
- */
-#define GTK_STYLE_PROPERTY_MARGIN "margin"
-
-/**
- * GTK_STYLE_PROPERTY_BORDER_RADIUS:
- *
- * A property holding the rendered element’s border radius in pixels as a #gint.
- */
-#define GTK_STYLE_PROPERTY_BORDER_RADIUS "border-radius"
-
-/**
- * GTK_STYLE_PROPERTY_BORDER_STYLE:
- *
- * A property holding the element’s border style as a #GtkBorderStyle.
- */
-#define GTK_STYLE_PROPERTY_BORDER_STYLE "border-style"
-
-/**
- * GTK_STYLE_PROPERTY_BORDER_COLOR:
- *
- * A property holding the element’s border color as a #GdkRGBA.
- */
-#define GTK_STYLE_PROPERTY_BORDER_COLOR "border-color"
-
-/**
- * GTK_STYLE_PROPERTY_BACKGROUND_IMAGE:
- *
- * A property holding the element’s background as a #cairo_pattern_t.
- */
-#define GTK_STYLE_PROPERTY_BACKGROUND_IMAGE "background-image"
-
 /* Predefined set of CSS classes */
 
 /**
@@ -180,8 +92,6 @@ struct _GtkStyleContextClass
  * A CSS class to match labels.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.16
  */
 #define GTK_STYLE_CLASS_LABEL "label"
 
@@ -263,8 +173,6 @@ struct _GtkStyleContextClass
  * A CSS class that gets added to windows which have client-side decorations.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.14
  */
 #define GTK_STYLE_CLASS_CSD "csd"
 
@@ -302,8 +210,6 @@ struct _GtkStyleContextClass
  * and text views.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.16
  */
 #define GTK_STYLE_CLASS_TOUCH_SELECTION "touch-selection"
 
@@ -334,32 +240,12 @@ struct _GtkStyleContextClass
  */
 #define GTK_STYLE_CLASS_TOOLBAR "toolbar"
 
-/**
- * GTK_STYLE_CLASS_PRIMARY_TOOLBAR:
- *
- * A CSS class to match primary toolbars.
- *
- * Refer to individual widget documentation for used style classes.
- */
-#define GTK_STYLE_CLASS_PRIMARY_TOOLBAR "primary-toolbar"
-
-/**
- * GTK_STYLE_CLASS_INLINE_TOOLBAR:
- *
- * A CSS class to match inline toolbars.
- *
- * Refer to individual widget documentation for used style classes.
- */
-#define GTK_STYLE_CLASS_INLINE_TOOLBAR "inline-toolbar"
-
 /**
  * GTK_STYLE_CLASS_STATUSBAR:
  *
  * A CSS class to match statusbars.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.16
  */
 #define GTK_STYLE_CLASS_STATUSBAR "statusbar"
 
@@ -411,7 +297,7 @@ struct _GtkStyleContextClass
 /**
  * GTK_STYLE_CLASS_SCROLLBARS_JUNCTION:
  *
- * A CSS class to match the junction area between an horizontal
+ * A CSS class to match the junction area between a horizontal
  * and vertical scrollbar, when they’re both shown.
  *
  * Refer to individual widget documentation for used style classes.
@@ -487,15 +373,6 @@ struct _GtkStyleContextClass
  */
 #define GTK_STYLE_CLASS_LINKED "linked"
 
-/**
- * GTK_STYLE_CLASS_GRIP:
- *
- * A CSS class defining a resize grip.
- *
- * Refer to individual widget documentation for used style classes.
- */
-#define GTK_STYLE_CLASS_GRIP "grip"
-
 /**
  * GTK_STYLE_CLASS_DOCK:
  *
@@ -544,7 +421,7 @@ struct _GtkStyleContextClass
 /**
  * GTK_STYLE_CLASS_SPINBUTTON:
  *
- * A CSS class defining an spinbutton.
+ * A CSS class defining a spinbutton.
  *
  * Refer to individual widget documentation for used style classes.
  */
@@ -803,8 +680,6 @@ struct _GtkStyleContextClass
  * a toplevel window.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.14
  */
 #define GTK_STYLE_CLASS_TITLE "title"
 
@@ -815,8 +690,6 @@ struct _GtkStyleContextClass
  * a toplevel window.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.14
  */
 #define GTK_STYLE_CLASS_SUBTITLE "subtitle"
 
@@ -828,8 +701,6 @@ struct _GtkStyleContextClass
  * a hidden page that changed state.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.12
  */
 #define GTK_STYLE_CLASS_NEEDS_ATTENTION "needs-attention"
 
@@ -840,8 +711,6 @@ struct _GtkStyleContextClass
  * primary suggested action in a specific context.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.12
  */
 #define GTK_STYLE_CLASS_SUGGESTED_ACTION "suggested-action"
 
@@ -853,8 +722,6 @@ struct _GtkStyleContextClass
  * to the user.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.12
  */
 #define GTK_STYLE_CLASS_DESTRUCTIVE_ACTION "destructive-action"
 
@@ -864,8 +731,6 @@ struct _GtkStyleContextClass
  * A CSS class that matches popovers.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.14
  */
 #define GTK_STYLE_CLASS_POPOVER "popover"
 
@@ -877,8 +742,6 @@ struct _GtkStyleContextClass
  * A CSS class that is added to the toplevel windows used for menus.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.14
  */
 #define GTK_STYLE_CLASS_POPUP "popup"
 
@@ -888,8 +751,6 @@ struct _GtkStyleContextClass
  * A CSS class that is added to message dialogs.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.14
  */
 #define GTK_STYLE_CLASS_MESSAGE_DIALOG "message-dialog"
 
@@ -901,8 +762,6 @@ struct _GtkStyleContextClass
  * without it.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.14
  */
 #define GTK_STYLE_CLASS_FLAT "flat"
 
@@ -923,8 +782,6 @@ struct _GtkStyleContextClass
  * area.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.14
  */
 #define GTK_STYLE_CLASS_OVERSHOOT "overshoot"
 
@@ -936,8 +793,6 @@ struct _GtkStyleContextClass
  * by scrolling.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.16
  */
 #define GTK_STYLE_CLASS_UNDERSHOOT "undershoot"
 
@@ -950,8 +805,6 @@ struct _GtkStyleContextClass
  * style it as black text on white background.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.16
  */
 #define GTK_STYLE_CLASS_PAPER "paper"
 
@@ -962,8 +815,6 @@ struct _GtkStyleContextClass
  * a monospace font.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.16
  */
 #define GTK_STYLE_CLASS_MONOSPACE "monospace"
 
@@ -974,60 +825,19 @@ struct _GtkStyleContextClass
  * Used by #GtkPaned.
  *
  * Refer to individual widget documentation for used style classes.
- *
- * Since: 3.16
  */
 #define GTK_STYLE_CLASS_WIDE "wide"
 
-/**
- * GTK_STYLE_REGION_ROW:
- *
- * A widget region name to define a treeview row.
- *
- * Deprecated: 3.20: Don't use regions.
- */
-#define GTK_STYLE_REGION_ROW "row"
-
-/**
- * GTK_STYLE_REGION_COLUMN:
- *
- * A widget region name to define a treeview column.
- *
- * Deprecated: 3.20: Don't use regions.
- */
-#define GTK_STYLE_REGION_COLUMN "column"
-
-/**
- * GTK_STYLE_REGION_COLUMN_HEADER:
- *
- * A widget region name to define a treeview column header.
- *
- * Deprecated: 3.20: Don't use regions.
- */
-#define GTK_STYLE_REGION_COLUMN_HEADER "column-header"
-
-/**
- * GTK_STYLE_REGION_TAB:
- *
- * A widget region name to define a notebook tab.
- *
- * Deprecated: 3.20: Don't use regions.
- */
-#define GTK_STYLE_REGION_TAB "tab"
-
 GDK_AVAILABLE_IN_ALL
 GType gtk_style_context_get_type (void) G_GNUC_CONST;
 
 GDK_AVAILABLE_IN_ALL
-GtkStyleContext * gtk_style_context_new (void);
-
+void gtk_style_context_add_provider_for_display    (GdkDisplay       *display,
+                                                    GtkStyleProvider *provider,
+                                                    guint             priority);
 GDK_AVAILABLE_IN_ALL
-void gtk_style_context_add_provider_for_screen    (GdkScreen        *screen,
-                                                   GtkStyleProvider *provider,
-                                                   guint             priority);
-GDK_AVAILABLE_IN_ALL
-void gtk_style_context_remove_provider_for_screen (GdkScreen        *screen,
-                                                   GtkStyleProvider *provider);
+void gtk_style_context_remove_provider_for_display (GdkDisplay       *display,
+                                                    GtkStyleProvider *provider);
 
 GDK_AVAILABLE_IN_ALL
 void gtk_style_context_add_provider    (GtkStyleContext  *context,
@@ -1043,51 +853,18 @@ void gtk_style_context_save    (GtkStyleContext *context);
 GDK_AVAILABLE_IN_ALL
 void gtk_style_context_restore (GtkStyleContext *context);
 
-GDK_AVAILABLE_IN_ALL
-GtkCssSection * gtk_style_context_get_section (GtkStyleContext *context,
-                                               const gchar     *property);
-GDK_AVAILABLE_IN_ALL
-void gtk_style_context_get_property (GtkStyleContext *context,
-                                     const gchar     *property,
-                                     GtkStateFlags    state,
-                                     GValue          *value);
-GDK_AVAILABLE_IN_ALL
-void gtk_style_context_get_valist   (GtkStyleContext *context,
-                                     GtkStateFlags    state,
-                                     va_list          args);
-GDK_AVAILABLE_IN_ALL
-void gtk_style_context_get          (GtkStyleContext *context,
-                                     GtkStateFlags    state,
-                                     ...) G_GNUC_NULL_TERMINATED;
-
 GDK_AVAILABLE_IN_ALL
 void          gtk_style_context_set_state    (GtkStyleContext *context,
                                               GtkStateFlags    flags);
 GDK_AVAILABLE_IN_ALL
 GtkStateFlags gtk_style_context_get_state    (GtkStyleContext *context);
 
-GDK_AVAILABLE_IN_3_10
+GDK_AVAILABLE_IN_ALL
 void          gtk_style_context_set_scale    (GtkStyleContext *context,
                                               gint             scale);
-GDK_AVAILABLE_IN_3_10
+GDK_AVAILABLE_IN_ALL
 gint          gtk_style_context_get_scale    (GtkStyleContext *context);
 
-GDK_DEPRECATED_IN_3_6
-gboolean      gtk_style_context_state_is_running (GtkStyleContext *context,
-                                                  GtkStateType     state,
-                                                  gdouble         *progress);
-
-GDK_AVAILABLE_IN_ALL
-void          gtk_style_context_set_path     (GtkStyleContext *context,
-                                              GtkWidgetPath   *path);
-GDK_AVAILABLE_IN_ALL
-const GtkWidgetPath * gtk_style_context_get_path (GtkStyleContext *context);
-GDK_AVAILABLE_IN_3_4
-void          gtk_style_context_set_parent   (GtkStyleContext *context,
-                                              GtkStyleContext *parent);
-GDK_AVAILABLE_IN_ALL
-GtkStyleContext *gtk_style_context_get_parent (GtkStyleContext *context);
-
 GDK_AVAILABLE_IN_ALL
 GList *  gtk_style_context_list_classes (GtkStyleContext *context);
 
@@ -1101,138 +878,35 @@ GDK_AVAILABLE_IN_ALL
 gboolean gtk_style_context_has_class    (GtkStyleContext *context,
                                          const gchar     *class_name);
 
-GDK_DEPRECATED_IN_3_14
-GList *  gtk_style_context_list_regions (GtkStyleContext *context);
-
-GDK_DEPRECATED_IN_3_14
-void     gtk_style_context_add_region    (GtkStyleContext    *context,
-                                          const gchar        *region_name,
-                                          GtkRegionFlags      flags);
-GDK_DEPRECATED_IN_3_14
-void     gtk_style_context_remove_region (GtkStyleContext    *context,
-                                          const gchar        *region_name);
-GDK_DEPRECATED_IN_3_14
-gboolean gtk_style_context_has_region    (GtkStyleContext    *context,
-                                          const gchar        *region_name,
-                                          GtkRegionFlags     *flags_return);
-
 GDK_AVAILABLE_IN_ALL
-void gtk_style_context_get_style_property (GtkStyleContext *context,
-                                           const gchar     *property_name,
-                                           GValue          *value);
+void        gtk_style_context_set_display (GtkStyleContext *context,
+                                           GdkDisplay      *display);
 GDK_AVAILABLE_IN_ALL
-void gtk_style_context_get_style_valist   (GtkStyleContext *context,
-                                           va_list          args);
-GDK_AVAILABLE_IN_ALL
-void gtk_style_context_get_style          (GtkStyleContext *context,
-                                           ...);
-
-GDK_DEPRECATED_IN_3_10_FOR(gtk_icon_theme_lookup_icon)
-GtkIconSet * gtk_style_context_lookup_icon_set (GtkStyleContext *context,
-                                                const gchar     *stock_id);
-GDK_DEPRECATED_IN_3_10
-GdkPixbuf  * gtk_icon_set_render_icon_pixbuf   (GtkIconSet      *icon_set,
-                                                GtkStyleContext *context,
-                                                GtkIconSize      size);
-GDK_DEPRECATED_IN_3_10
-cairo_surface_t  *
-gtk_icon_set_render_icon_surface               (GtkIconSet      *icon_set,
-						GtkStyleContext *context,
-						GtkIconSize      size,
-						int              scale,
-						GdkWindow       *for_window);
-
-GDK_AVAILABLE_IN_ALL
-void        gtk_style_context_set_screen (GtkStyleContext *context,
-                                          GdkScreen       *screen);
-GDK_AVAILABLE_IN_ALL
-GdkScreen * gtk_style_context_get_screen (GtkStyleContext *context);
-
-GDK_AVAILABLE_IN_3_8
-void           gtk_style_context_set_frame_clock (GtkStyleContext *context,
-                                                  GdkFrameClock   *frame_clock);
-GDK_AVAILABLE_IN_3_8
-GdkFrameClock *gtk_style_context_get_frame_clock (GtkStyleContext *context);
-
-GDK_DEPRECATED_IN_3_8_FOR(gtk_style_context_set_state)
-void             gtk_style_context_set_direction (GtkStyleContext  *context,
-                                                  GtkTextDirection  direction);
-GDK_DEPRECATED_IN_3_8_FOR(gtk_style_context_get_state)
-GtkTextDirection gtk_style_context_get_direction (GtkStyleContext  *context);
-
-GDK_AVAILABLE_IN_ALL
-void             gtk_style_context_set_junction_sides (GtkStyleContext  *context,
-                                                       GtkJunctionSides  sides);
-GDK_AVAILABLE_IN_ALL
-GtkJunctionSides gtk_style_context_get_junction_sides (GtkStyleContext  *context);
+GdkDisplay *gtk_style_context_get_display (GtkStyleContext *context);
 
 GDK_AVAILABLE_IN_ALL
 gboolean gtk_style_context_lookup_color (GtkStyleContext *context,
                                          const gchar     *color_name,
                                          GdkRGBA         *color);
 
-GDK_DEPRECATED_IN_3_6
-void  gtk_style_context_notify_state_change (GtkStyleContext *context,
-                                             GdkWindow       *window,
-                                             gpointer         region_id,
-                                             GtkStateType     state,
-                                             gboolean         state_value);
-GDK_DEPRECATED_IN_3_6
-void  gtk_style_context_cancel_animations   (GtkStyleContext *context,
-                                             gpointer         region_id);
-GDK_DEPRECATED_IN_3_6
-void  gtk_style_context_scroll_animations   (GtkStyleContext *context,
-                                             GdkWindow       *window,
-                                             gint             dx,
-                                             gint             dy);
-
-GDK_DEPRECATED_IN_3_6
-void gtk_style_context_push_animatable_region (GtkStyleContext *context,
-                                               gpointer         region_id);
-GDK_DEPRECATED_IN_3_6
-void gtk_style_context_pop_animatable_region  (GtkStyleContext *context);
-
 /* Some helper functions to retrieve most common properties */
 GDK_AVAILABLE_IN_ALL
 void gtk_style_context_get_color            (GtkStyleContext *context,
-                                             GtkStateFlags    state,
                                              GdkRGBA         *color);
-GDK_DEPRECATED_IN_3_16_FOR(gtk_render_background)
-void gtk_style_context_get_background_color (GtkStyleContext *context,
-                                             GtkStateFlags    state,
-                                             GdkRGBA         *color);
-GDK_DEPRECATED_IN_3_16_FOR(gtk_render_frame)
-void gtk_style_context_get_border_color     (GtkStyleContext *context,
-                                             GtkStateFlags    state,
-                                             GdkRGBA         *color);
-
-GDK_DEPRECATED_IN_3_8_FOR(gtk_style_context_get)
-const PangoFontDescription *
-     gtk_style_context_get_font             (GtkStyleContext *context,
-                                             GtkStateFlags    state);
 GDK_AVAILABLE_IN_ALL
 void gtk_style_context_get_border           (GtkStyleContext *context,
-                                             GtkStateFlags    state,
                                              GtkBorder       *border);
 GDK_AVAILABLE_IN_ALL
 void gtk_style_context_get_padding          (GtkStyleContext *context,
-                                             GtkStateFlags    state,
                                              GtkBorder       *padding);
 GDK_AVAILABLE_IN_ALL
 void gtk_style_context_get_margin           (GtkStyleContext *context,
-                                             GtkStateFlags    state,
                                              GtkBorder       *margin);
 
-GDK_DEPRECATED_IN_3_12
-void gtk_style_context_invalidate           (GtkStyleContext *context);
 GDK_AVAILABLE_IN_ALL
-void gtk_style_context_reset_widgets        (GdkScreen       *screen);
+void gtk_style_context_reset_widgets        (GdkDisplay      *display);
 
-GDK_DEPRECATED_IN_3_18_FOR(gtk_render_background)
-void gtk_style_context_set_background       (GtkStyleContext *context,
-                                             GdkWindow       *window);
-
-GDK_AVAILABLE_IN_3_4
+GDK_AVAILABLE_IN_ALL
 void        gtk_render_insertion_cursor
                                    (GtkStyleContext     *context,
                                     cairo_t             *cr,
@@ -1241,21 +915,15 @@ void        gtk_render_insertion_cursor
                                     PangoLayout         *layout,
                                     int                  index,
                                     PangoDirection       direction);
-GDK_DEPRECATED_IN_3_4
-void   gtk_draw_insertion_cursor    (GtkWidget          *widget,
-                                     cairo_t            *cr,
-                                     const GdkRectangle *location,
-                                     gboolean            is_primary,
-                                     GtkTextDirection    direction,
-                                     gboolean            draw_arrow);
 
 typedef enum {
   GTK_STYLE_CONTEXT_PRINT_NONE         = 0,
   GTK_STYLE_CONTEXT_PRINT_RECURSE      = 1 << 0,
-  GTK_STYLE_CONTEXT_PRINT_SHOW_STYLE   = 1 << 1
+  GTK_STYLE_CONTEXT_PRINT_SHOW_STYLE   = 1 << 1,
+  GTK_STYLE_CONTEXT_PRINT_SHOW_CHANGE  = 1 << 2
 } GtkStyleContextPrintFlags;
 
-GDK_AVAILABLE_IN_3_20
+GDK_AVAILABLE_IN_ALL
 char * gtk_style_context_to_string (GtkStyleContext           *context,
                                     GtkStyleContextPrintFlags  flags);
 
