@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -24,15 +22,14 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
+#ifndef __GTK_TEXT_BUFFER_H__
+#define __GTK_TEXT_BUFFER_H__
+
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
-#ifndef __GTK_TEXT_BUFFER_H__
-#define __GTK_TEXT_BUFFER_H__
-
 #include <gtk/gtkwidget.h>
-#include <gtk/gtkclipboard.h>
 #include <gtk/gtktexttagtable.h>
 #include <gtk/gtktextiter.h>
 #include <gtk/gtktextmark.h>
@@ -45,11 +42,18 @@ G_BEGIN_DECLS
  * GtkTextBTree is the PRIVATE internal representation of it.
  */
 
-/* these values are used as "info" for the targets contained in the
- * lists returned by gtk_text_buffer_get_copy,paste_target_list()
+/**
+ * GtkTextBufferTargetInfo:
+ * @GTK_TEXT_BUFFER_TARGET_INFO_BUFFER_CONTENTS: Buffer contents
+ * @GTK_TEXT_BUFFER_TARGET_INFO_RICH_TEXT: Rich text
+ * @GTK_TEXT_BUFFER_TARGET_INFO_TEXT: Text
  *
- * the enum counts down from G_MAXUINT to avoid clashes with application
- * added drag destinations which usually start at 0.
+ * These values are used as “info” for the targets contained in the
+ * lists returned by gtk_text_buffer_get_copy_target_list() and
+ * gtk_text_buffer_get_paste_target_list().
+ *
+ * The values counts down from `-1` to avoid clashes
+ * with application added drag destinations which usually start at 0.
  */
 typedef enum
 {
@@ -77,60 +81,75 @@ struct _GtkTextBuffer
   GtkTextBufferPrivate *priv;
 };
 
+/**
+ * GtkTextBufferClass:
+ * @parent_class: The object class structure needs to be the first.
+ * @insert_text: The class handler for the #GtkTextBuffer::insert-text signal.
+ * @insert_paintable: The class handler for the #GtkTextBuffer::insert-paintable signal.
+ * @insert_child_anchor: The class handler for the #GtkTextBuffer::insert-child-anchor signal.
+ * @delete_range: The class handler for the #GtkTextBuffer::delete-range signal.
+ * @changed: The class handler for the #GtkTextBuffer::changed signal.
+ * @modified_changed: The class handler for the #GtkTextBuffer::modified-changed signal.
+ * @mark_set: The class handler for the #GtkTextBuffer::mark-set signal.
+ * @mark_deleted: The class handler for the #GtkTextBuffer::mark-deleted signal.
+ * @apply_tag: The class handler for the #GtkTextBuffer::apply-tag signal.
+ * @remove_tag: The class handler for the #GtkTextBuffer::remove-tag signal.
+ * @begin_user_action: The class handler for the #GtkTextBuffer::begin-user-action signal.
+ * @end_user_action: The class handler for the #GtkTextBuffer::end-user-action signal.
+ * @paste_done: The class handler for the #GtkTextBuffer::paste-done signal.
+ */
 struct _GtkTextBufferClass
 {
   GObjectClass parent_class;
 
-  void (* insert_text)     (GtkTextBuffer *buffer,
-                            GtkTextIter *pos,
-                            const gchar *new_text,
-                            gint new_text_length);
+  void (* insert_text)            (GtkTextBuffer      *buffer,
+                                   GtkTextIter        *pos,
+                                   const gchar        *new_text,
+                                   gint                new_text_length);
 
-  void (* insert_pixbuf)   (GtkTextBuffer *buffer,
-                            GtkTextIter   *iter,
-                            GdkPixbuf     *pixbuf);
+  void (* insert_paintable)       (GtkTextBuffer      *buffer,
+                                   GtkTextIter        *iter,
+                                   GdkPaintable       *paintable);
 
-  void (* insert_child_anchor)   (GtkTextBuffer      *buffer,
-                                  GtkTextIter        *iter,
-                                  GtkTextChildAnchor *anchor);
+  void (* insert_child_anchor)    (GtkTextBuffer      *buffer,
+                                   GtkTextIter        *iter,
+                                   GtkTextChildAnchor *anchor);
 
-  void (* delete_range)     (GtkTextBuffer *buffer,
-                             GtkTextIter   *start,
-                             GtkTextIter   *end);
+  void (* delete_range)           (GtkTextBuffer      *buffer,
+                                   GtkTextIter        *start,
+                                   GtkTextIter        *end);
 
-  /* Only for text/widgets/pixbuf changed, marks/tags don't cause this
-   * to be emitted
-   */
-  void (* changed)         (GtkTextBuffer *buffer);
+  void (* changed)                (GtkTextBuffer      *buffer);
 
+  void (* modified_changed)       (GtkTextBuffer      *buffer);
 
-  /* New value for the modified flag */
-  void (* modified_changed)   (GtkTextBuffer *buffer);
+  void (* mark_set)               (GtkTextBuffer      *buffer,
+                                   const GtkTextIter  *location,
+                                   GtkTextMark        *mark);
 
-  /* Mark moved or created */
-  void (* mark_set)           (GtkTextBuffer *buffer,
-                               const GtkTextIter *location,
-                               GtkTextMark *mark);
+  void (* mark_deleted)           (GtkTextBuffer      *buffer,
+                                   GtkTextMark        *mark);
 
-  void (* mark_deleted)       (GtkTextBuffer *buffer,
-                               GtkTextMark *mark);
+  void (* apply_tag)              (GtkTextBuffer      *buffer,
+                                   GtkTextTag         *tag,
+                                   const GtkTextIter  *start,
+                                   const GtkTextIter  *end);
 
-  void (* apply_tag)          (GtkTextBuffer *buffer,
-                               GtkTextTag *tag,
-                               const GtkTextIter *start,
-                               const GtkTextIter *end);
+  void (* remove_tag)             (GtkTextBuffer      *buffer,
+                                   GtkTextTag         *tag,
+                                   const GtkTextIter  *start,
+                                   const GtkTextIter  *end);
 
-  void (* remove_tag)         (GtkTextBuffer *buffer,
-                               GtkTextTag *tag,
-                               const GtkTextIter *start,
-                               const GtkTextIter *end);
+  void (* begin_user_action)      (GtkTextBuffer      *buffer);
 
-  /* Called at the start and end of an atomic user action */
-  void (* begin_user_action)  (GtkTextBuffer *buffer);
-  void (* end_user_action)    (GtkTextBuffer *buffer);
+  void (* end_user_action)        (GtkTextBuffer      *buffer);
 
-  void (* paste_done)         (GtkTextBuffer *buffer,
-                               GtkClipboard  *clipboard);
+  void (* paste_done)             (GtkTextBuffer      *buffer,
+                                   GdkClipboard       *clipboard);
+  void (* undo)                   (GtkTextBuffer      *buffer);
+  void (* redo)                   (GtkTextBuffer      *buffer);
+
+  /*< private >*/
 
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
@@ -139,52 +158,65 @@ struct _GtkTextBufferClass
   void (*_gtk_reserved4) (void);
 };
 
+GDK_AVAILABLE_IN_ALL
 GType        gtk_text_buffer_get_type       (void) G_GNUC_CONST;
 
 
 
 /* table is NULL to create a new one */
+GDK_AVAILABLE_IN_ALL
 GtkTextBuffer *gtk_text_buffer_new            (GtkTextTagTable *table);
+GDK_AVAILABLE_IN_ALL
 gint           gtk_text_buffer_get_line_count (GtkTextBuffer   *buffer);
+GDK_AVAILABLE_IN_ALL
 gint           gtk_text_buffer_get_char_count (GtkTextBuffer   *buffer);
 
 
+GDK_AVAILABLE_IN_ALL
 GtkTextTagTable* gtk_text_buffer_get_tag_table (GtkTextBuffer  *buffer);
 
 /* Delete whole buffer, then insert */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_set_text          (GtkTextBuffer *buffer,
                                         const gchar   *text,
                                         gint           len);
 
 /* Insert into the buffer */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_insert            (GtkTextBuffer *buffer,
                                         GtkTextIter   *iter,
                                         const gchar   *text,
                                         gint           len);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_insert_at_cursor  (GtkTextBuffer *buffer,
                                         const gchar   *text,
                                         gint           len);
 
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_insert_interactive           (GtkTextBuffer *buffer,
                                                        GtkTextIter   *iter,
                                                        const gchar   *text,
                                                        gint           len,
                                                        gboolean       default_editable);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_insert_interactive_at_cursor (GtkTextBuffer *buffer,
                                                        const gchar   *text,
                                                        gint           len,
                                                        gboolean       default_editable);
 
+GDK_AVAILABLE_IN_ALL
 void     gtk_text_buffer_insert_range             (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
                                                    const GtkTextIter *start,
                                                    const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_insert_range_interactive (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
                                                    const GtkTextIter *start,
                                                    const GtkTextIter *end,
                                                    gboolean           default_editable);
 
+GDK_AVAILABLE_IN_ALL
 void    gtk_text_buffer_insert_with_tags          (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
                                                    const gchar       *text,
@@ -192,6 +224,7 @@ void    gtk_text_buffer_insert_with_tags          (GtkTextBuffer     *buffer,
                                                    GtkTextTag        *first_tag,
                                                    ...) G_GNUC_NULL_TERMINATED;
 
+GDK_AVAILABLE_IN_ALL
 void    gtk_text_buffer_insert_with_tags_by_name  (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
                                                    const gchar       *text,
@@ -199,72 +232,97 @@ void    gtk_text_buffer_insert_with_tags_by_name  (GtkTextBuffer     *buffer,
                                                    const gchar       *first_tag_name,
                                                    ...) G_GNUC_NULL_TERMINATED;
 
+GDK_AVAILABLE_IN_ALL
+void     gtk_text_buffer_insert_markup            (GtkTextBuffer     *buffer,
+                                                   GtkTextIter       *iter,
+                                                   const gchar       *markup,
+                                                   gint               len);
+
 /* Delete from the buffer */
+GDK_AVAILABLE_IN_ALL
 void     gtk_text_buffer_delete             (GtkTextBuffer *buffer,
 					     GtkTextIter   *start,
 					     GtkTextIter   *end);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_delete_interactive (GtkTextBuffer *buffer,
 					     GtkTextIter   *start_iter,
 					     GtkTextIter   *end_iter,
 					     gboolean       default_editable);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_backspace          (GtkTextBuffer *buffer,
 					     GtkTextIter   *iter,
 					     gboolean       interactive,
 					     gboolean       default_editable);
 
 /* Obtain strings from the buffer */
+GDK_AVAILABLE_IN_ALL
 gchar          *gtk_text_buffer_get_text            (GtkTextBuffer     *buffer,
                                                      const GtkTextIter *start,
                                                      const GtkTextIter *end,
                                                      gboolean           include_hidden_chars);
 
+GDK_AVAILABLE_IN_ALL
 gchar          *gtk_text_buffer_get_slice           (GtkTextBuffer     *buffer,
                                                      const GtkTextIter *start,
                                                      const GtkTextIter *end,
                                                      gboolean           include_hidden_chars);
 
-/* Insert a pixbuf */
-void gtk_text_buffer_insert_pixbuf         (GtkTextBuffer *buffer,
+/* Insert a paintable */
+GDK_AVAILABLE_IN_ALL
+void gtk_text_buffer_insert_paintable      (GtkTextBuffer *buffer,
                                             GtkTextIter   *iter,
-                                            GdkPixbuf     *pixbuf);
+                                            GdkPaintable  *paintable);
 
 /* Insert a child anchor */
+GDK_AVAILABLE_IN_ALL
 void               gtk_text_buffer_insert_child_anchor (GtkTextBuffer      *buffer,
                                                         GtkTextIter        *iter,
                                                         GtkTextChildAnchor *anchor);
 
 /* Convenience, create and insert a child anchor */
+GDK_AVAILABLE_IN_ALL
 GtkTextChildAnchor *gtk_text_buffer_create_child_anchor (GtkTextBuffer *buffer,
                                                          GtkTextIter   *iter);
 
 /* Mark manipulation */
+GDK_AVAILABLE_IN_ALL
 void           gtk_text_buffer_add_mark    (GtkTextBuffer     *buffer,
                                             GtkTextMark       *mark,
                                             const GtkTextIter *where);
+GDK_AVAILABLE_IN_ALL
 GtkTextMark   *gtk_text_buffer_create_mark (GtkTextBuffer     *buffer,
                                             const gchar       *mark_name,
                                             const GtkTextIter *where,
                                             gboolean           left_gravity);
+GDK_AVAILABLE_IN_ALL
 void           gtk_text_buffer_move_mark   (GtkTextBuffer     *buffer,
                                             GtkTextMark       *mark,
                                             const GtkTextIter *where);
+GDK_AVAILABLE_IN_ALL
 void           gtk_text_buffer_delete_mark (GtkTextBuffer     *buffer,
                                             GtkTextMark       *mark);
+GDK_AVAILABLE_IN_ALL
 GtkTextMark*   gtk_text_buffer_get_mark    (GtkTextBuffer     *buffer,
                                             const gchar       *name);
 
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_move_mark_by_name   (GtkTextBuffer     *buffer,
                                           const gchar       *name,
                                           const GtkTextIter *where);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_delete_mark_by_name (GtkTextBuffer     *buffer,
                                           const gchar       *name);
 
+GDK_AVAILABLE_IN_ALL
 GtkTextMark* gtk_text_buffer_get_insert          (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
 GtkTextMark* gtk_text_buffer_get_selection_bound (GtkTextBuffer *buffer);
 
 /* efficiently move insert and selection_bound at the same time */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_place_cursor (GtkTextBuffer     *buffer,
                                    const GtkTextIter *where);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_select_range (GtkTextBuffer     *buffer,
                                    const GtkTextIter *ins,
 				   const GtkTextIter *bound);
@@ -272,22 +330,27 @@ void gtk_text_buffer_select_range (GtkTextBuffer     *buffer,
 
 
 /* Tag manipulation */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_apply_tag             (GtkTextBuffer     *buffer,
                                             GtkTextTag        *tag,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_remove_tag            (GtkTextBuffer     *buffer,
                                             GtkTextTag        *tag,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_apply_tag_by_name     (GtkTextBuffer     *buffer,
                                             const gchar       *name,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_remove_tag_by_name    (GtkTextBuffer     *buffer,
                                             const gchar       *name,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_remove_all_tags       (GtkTextBuffer     *buffer,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
@@ -296,6 +359,7 @@ void gtk_text_buffer_remove_all_tags       (GtkTextBuffer     *buffer,
 /* You can either ignore the return value, or use it to
  * set the attributes of the tag. tag_name can be NULL
  */
+GDK_AVAILABLE_IN_ALL
 GtkTextTag    *gtk_text_buffer_create_tag (GtkTextBuffer *buffer,
                                            const gchar   *tag_name,
                                            const gchar   *first_property_name,
@@ -304,31 +368,40 @@ GtkTextTag    *gtk_text_buffer_create_tag (GtkTextBuffer *buffer,
 /* Obtain iterators pointed at various places, then you can move the
  * iterator around using the GtkTextIter operators
  */
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_line_offset (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               gint           line_number,
                                               gint           char_offset);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_line_index  (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               gint           line_number,
                                               gint           byte_index);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_offset      (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               gint           char_offset);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_line        (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               gint           line_number);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_start_iter          (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_end_iter            (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_bounds              (GtkTextBuffer *buffer,
                                               GtkTextIter   *start,
                                               GtkTextIter   *end);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_mark        (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter,
                                               GtkTextMark   *mark);
 
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_iter_at_child_anchor (GtkTextBuffer      *buffer,
                                                GtkTextIter        *iter,
                                                GtkTextChildAnchor *anchor);
@@ -342,68 +415,75 @@ void gtk_text_buffer_get_iter_at_child_anchor (GtkTextBuffer      *buffer,
    flag, but if you would like them to you can connect a handler to
    the tag/mark signals and call set_modified in your handler */
 
+GDK_AVAILABLE_IN_ALL
 gboolean        gtk_text_buffer_get_modified            (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_set_modified            (GtkTextBuffer *buffer,
                                                          gboolean       setting);
 
+GDK_AVAILABLE_IN_ALL
 gboolean        gtk_text_buffer_get_has_selection       (GtkTextBuffer *buffer);
 
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_add_selection_clipboard    (GtkTextBuffer     *buffer,
-						 GtkClipboard      *clipboard);
+						 GdkClipboard      *clipboard);
+GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_remove_selection_clipboard (GtkTextBuffer     *buffer,
-						 GtkClipboard      *clipboard);
+						 GdkClipboard      *clipboard);
 
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_cut_clipboard           (GtkTextBuffer *buffer,
-							 GtkClipboard  *clipboard,
+							 GdkClipboard  *clipboard,
                                                          gboolean       default_editable);
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_copy_clipboard          (GtkTextBuffer *buffer,
-							 GtkClipboard  *clipboard);
+							 GdkClipboard  *clipboard);
+GDK_AVAILABLE_IN_ALL
 void            gtk_text_buffer_paste_clipboard         (GtkTextBuffer *buffer,
-							 GtkClipboard  *clipboard,
+							 GdkClipboard  *clipboard,
 							 GtkTextIter   *override_location,
                                                          gboolean       default_editable);
 
+GDK_AVAILABLE_IN_ALL
 gboolean        gtk_text_buffer_get_selection_bounds    (GtkTextBuffer *buffer,
                                                          GtkTextIter   *start,
                                                          GtkTextIter   *end);
+GDK_AVAILABLE_IN_ALL
 gboolean        gtk_text_buffer_delete_selection        (GtkTextBuffer *buffer,
                                                          gboolean       interactive,
                                                          gboolean       default_editable);
 
-/* Called to specify atomic user actions, used to implement undo */
-void            gtk_text_buffer_begin_user_action       (GtkTextBuffer *buffer);
-void            gtk_text_buffer_end_user_action         (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+GdkContentProvider *
+                gtk_text_buffer_get_selection_content    (GtkTextBuffer *buffer);
 
-GtkTargetList * gtk_text_buffer_get_copy_target_list    (GtkTextBuffer *buffer);
-GtkTargetList * gtk_text_buffer_get_paste_target_list   (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+gboolean        gtk_text_buffer_get_can_undo              (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+gboolean        gtk_text_buffer_get_can_redo              (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+gboolean        gtk_text_buffer_get_enable_undo           (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+void            gtk_text_buffer_set_enable_undo           (GtkTextBuffer *buffer,
+                                                           gboolean       enable_undo);
+GDK_AVAILABLE_IN_ALL
+guint           gtk_text_buffer_get_max_undo_levels       (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+void            gtk_text_buffer_set_max_undo_levels       (GtkTextBuffer *buffer,
+                                                           guint          max_undo_levels);
+GDK_AVAILABLE_IN_ALL
+void            gtk_text_buffer_undo                      (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+void            gtk_text_buffer_redo                      (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+void            gtk_text_buffer_begin_irreversible_action (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+void            gtk_text_buffer_end_irreversible_action   (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+void            gtk_text_buffer_begin_user_action         (GtkTextBuffer *buffer);
+GDK_AVAILABLE_IN_ALL
+void            gtk_text_buffer_end_user_action           (GtkTextBuffer *buffer);
 
-/* INTERNAL private stuff */
-void            _gtk_text_buffer_spew                  (GtkTextBuffer      *buffer);
-
-GtkTextBTree*   _gtk_text_buffer_get_btree             (GtkTextBuffer      *buffer);
-
-const PangoLogAttr* _gtk_text_buffer_get_line_log_attrs (GtkTextBuffer     *buffer,
-                                                         const GtkTextIter *anywhere_in_line,
-                                                         gint              *char_len);
-
-void _gtk_text_buffer_notify_will_remove_tag (GtkTextBuffer *buffer,
-                                              GtkTextTag    *tag);
-
-void _gtk_text_buffer_get_text_before (GtkTextBuffer   *buffer,
-                                       AtkTextBoundary  boundary_type,
-                                       GtkTextIter     *position,
-                                       GtkTextIter     *start,
-                                       GtkTextIter     *end);
-void _gtk_text_buffer_get_text_at     (GtkTextBuffer   *buffer,
-                                       AtkTextBoundary  boundary_type,
-                                       GtkTextIter     *position,
-                                       GtkTextIter     *start,
-                                       GtkTextIter     *end);
-void _gtk_text_buffer_get_text_after  (GtkTextBuffer   *buffer,
-                                       AtkTextBoundary  boundary_type,
-                                       GtkTextIter     *position,
-                                       GtkTextIter     *start,
-                                       GtkTextIter     *end);
 
 G_END_DECLS
 
